# ML Pipeline

A machine learning pipeline for Exploratory Data Analysis (EDA), data preprocessing, model training, and evaluation. This package helps to quickly analyze datasets, preprocess data, and train models like Random Forest or XGBoost with detailed evaluation metrics.

## Features
-Upload any csv dataset and run ML Pipeline from EDA to Model validation
- Perform EDA and visualize data
- Handle missing values and scale data
- Encode categorical data
- Train Random Forest or XGBoost models
- Evaluate models using F1 score, R², MSE, etc.

## Installation

You can install the package via pip:

```bash
pip install ml_pipeline_dashboard
> launch_ml_pipeline
